jupyter_client: Jupyter protocol implementation and client libraries
====================================================================

Description
-----------

Jupyter protocol implementation and client libraries

License
-------

BSD 3-Clause License

Upstream Contact
----------------

https://pypi.org/project/jupyter-client/

